import coshsh
from coshsh.application import Application
from coshsh.templaterule import TemplateRule
from coshsh.util import compare_attr

def __mi_ident__(params={}):
    if coshsh.util.compare_attr("type", params, "dos"):
        return DOS


class DOS(coshsh.application.Application):
    marker = "corporate"
    template_rules = [
        coshsh.templaterule.TemplateRule(needsattr=None, 
            template="os_dos_default"),
    ]




#!/usr/bin/env python
#-*- encoding: utf-8 -*-
#
# Copyright 2010-2012 Gerhard Lausser.
# This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

import os
import re
import logging
import coshsh
from coshsh.host import Host
from coshsh.datasource import Datasource
from coshsh.application import Application
from coshsh.monitoringdetail import MonitoringDetail
from coshsh.util import compare_attr

logger = logging.getLogger('coshsh')

def __ds_ident__(params={}):
    if coshsh.util.compare_attr("type", params, "lazy"):
        return LazyDs

class MyHost(coshsh.host.Host):
    def __init__(self, params={}):
        superclass = super(MyHost, self)
        superclass.__init__(params)
        self.my_host = True

class LazyDs(coshsh.datasource.Datasource):
    class_only_the_test_simplesample = True
    def __init__(self, **kwargs):
        print kwargs
        self.name = kwargs["name"]
        self.dir = kwargs["dir"]
        self.only_the_test_simplesample = True

    def read(self, filter=None, objects={}, **kwargs):
        logger.info('read items from simplesample')
        self.objects = objects
        hostdata = {
            'host_name': 'test_host_0',
            'address': '127.0.0.9',
            'type': 'test',
            'hardware': 'Vmware',
            'virtual': 'vs',
            'notification_period': '7x24',
            'location': 'esxsrv10',
            'department': 'test',
        }
        self.add('hosts', MyHost(hostdata))
        appdata = {
            'host_name': 'test_host_0',
            'name': 'os',
            'type': 'Windows',
            'component': '',
            'version': '2008',
            'patchlevel': 'R2',
            'host_name': 'test_host_0',
            'check_period': '7x24',
        }
        self.add('applications', coshsh.application.Application(appdata))
        detdata = {
            'host_name': 'test_host_0',
            'name': 'os',
            'type': 'Windows',
            'monitoring_type': 'KEYVALUES',
            'monitoring_0': 'huhu',
            'monitoring_1': 'dada',
        }
        self.add('details', coshsh.monitoringdetail.MonitoringDetail(detdata))




import unittest
import os
import sys
import shutil
import string
from optparse import OptionParser
import ConfigParser
import logging


sys.dont_write_bytecode = True

import coshsh
from coshsh.generator import Generator


class CoshshTest(unittest.TestCase):
    def print_header(self):
        print "#" * 80 + "\n" + "#" + " " * 78 + "#"
        print "#" + string.center(self.id(), 78) + "#"
        print "#" + " " * 78 + "#\n" + "#" * 80 + "\n"

    def setUp(self):
        shutil.rmtree("./var/objects/test13", True)
        os.makedirs("./var/objects/test13")
        self.config = ConfigParser.ConfigParser()
        self.config.read('etc/coshsh.cfg')
        self.generator = coshsh.generator.Generator()
        self.generator.setup_logging(scrnloglevel=logging.DEBUG)

    def tearDown(self):
        #shutil.rmtree("./var/objects/test1", True)
        print 

    def test_check_class_order(self):
        """
        classes_dir = ./recipes/test13d/classes,./recipes/test13c/classes
        templates_dir = ./recipes/test13d/templates,./recipes/test13c/templates

        department		corporate		default
	os_linux.py		os_linux.py		os_linux.py
	os_beos.py
	os_aix.py		os_aix.py
				os_dos.py

        department		corporate		default
	os_linux_default.tpl	os_linux_default.tpl	os_linux_default.tpl
				os_beos_default.tpl
	os_aix_default.tpl	os_aix_default.tpl
	os_dos_default.tpl
	

	
        """
        self.print_header()
        self.generator.add_recipe(name='test13', **dict(self.config.items('recipe_TEST13')))
        self.config.set("datasource_CSV13", "name", "csv13")
        cfg = self.config.items("datasource_CSV13")
        self.generator.recipes['test13'].add_datasource(**dict(cfg))

        # remove target dir / create empty
        self.generator.recipes['test13'].count_before_objects()
        self.generator.recipes['test13'].cleanup_target_dir()

        self.generator.recipes['test13'].prepare_target_dir()
        # check target

        # read the datasources
        self.generator.recipes['test13'].collect()

        # for each host, application get the corresponding template files
        # get the template files and cache them in a struct owned by the recipe
        # resolve the templates and attach the result as config_files to host/app
        self.generator.recipes['test13'].render()
        self.assert_(hasattr(self.generator.recipes['test13'].objects['hosts']['linux_host'], 'config_files'))
        self.assert_('host.cfg' in self.generator.recipes['test13'].objects['hosts']['linux_host'].config_files)

        # write hosts/apps to the filesystem
        self.generator.recipes['test13'].output()
        self.assert_(os.path.exists("var/objects/test13/dynamic/hosts"))
        self.assert_(os.path.exists("var/objects/test13/dynamic/hosts/linux_host"))
        self.assert_(os.path.exists("var/objects/test13/dynamic/hosts/linux_host/os_linux_default.cfg"))
        self.assert_(os.path.exists("var/objects/test13/dynamic/hosts/aix_host/os_aix_default.cfg"))
        self.assert_(os.path.exists("var/objects/test13/dynamic/hosts/beos_host/os_beos_default.cfg"))
        self.assert_(os.path.exists("var/objects/test13/dynamic/hosts/dos_host/os_dos_default.cfg"))
        self.assert_(os.path.exists("var/objects/test13/dynamic/hosts/windows_host/os_windows_default.cfg"))

        # test classes
        print self.generator.recipes['test13'].objects['applications']
        self.assert_(self.generator.recipes['test13'].objects['applications']['linux_host+os+red hat'].marker == 'department')
        self.assert_(self.generator.recipes['test13'].objects['applications']['beos_host+os+beos'].marker == 'department')
        self.assert_(self.generator.recipes['test13'].objects['applications']['aix_host+os+aix'].marker == 'department')
        self.assert_(self.generator.recipes['test13'].objects['applications']['dos_host+os+dos'].marker == 'corporate')
        self.assert_(not hasattr(self.generator.recipes['test13'].objects['applications']['windows_host+os+windows'], 'marker'))
        # test templates
        os_linux_default_cfg = open("var/objects/test13/dynamic/hosts/linux_host/os_linux_default.cfg").read()
        self.assert_('department' in os_linux_default_cfg)
        os_beos_default_cfg = open("var/objects/test13/dynamic/hosts/beos_host/os_beos_default.cfg").read()
        self.assert_('corporate' in os_beos_default_cfg)
        os_aix_default_cfg = open("var/objects/test13/dynamic/hosts/aix_host/os_aix_default.cfg").read()
        self.assert_('department' in os_aix_default_cfg)
        os_dos_default_cfg = open("var/objects/test13/dynamic/hosts/dos_host/os_dos_default.cfg").read()
        self.assert_('department' in os_dos_default_cfg)
        os_windows_default_cfg = open("var/objects/test13/dynamic/hosts/windows_host/os_windows_default.cfg").read()
        self.assert_('define' in os_windows_default_cfg)
        host_cfg = open("var/objects/test13/dynamic/hosts/windows_host/host.cfg").read()
        self.assert_('corporate host' in host_cfg)


if __name__ == '__main__':
    unittest.main()





import coshsh
from coshsh.monitoringdetail import MonitoringDetail

def __detail_ident__(params={}):
    if params["monitoring_type"] == "CUSTOMMACRO":
        return MonitoringDetailCustomMacro


class MonitoringDetailCustomMacro(coshsh.monitoringdetail.MonitoringDetail):
    """
    """
    property = "custom_macros"
    property_type = dict

    def __init__(self, params):
        self.monitoring_type = params["monitoring_type"]
        self.key = params["monitoring_0"]
        self.value = params["monitoring_1"]

    def __str__(self):
        return "%s: %s" % (self.key, self.value)




import unittest
import os
import sys
import shutil
import string
from optparse import OptionParser
import ConfigParser
import logging
import pprint
from subprocess import Popen, PIPE, STDOUT


sys.dont_write_bytecode = True

import coshsh
from coshsh.generator import Generator
from coshsh.datasource import Datasource
from coshsh.application import Application
from coshsh.util import odict

class CoshshTest(unittest.TestCase):
    def print_header(self):
        print "#" * 80 + "\n" + "#" + " " * 78 + "#"
        print "#" + string.center(self.id(), 78) + "#"
        print "#" + " " * 78 + "#\n" + "#" * 80 + "\n"

    def setUp(self):
        self.config = ConfigParser.ConfigParser()
        self.config.read('etc/coshsh.cfg')
        self.generator = coshsh.generator.Generator()
        self.generator.setup_logging()

    def tearDown(self):
        pass

    def clean_generator(self):
        self.generator = None
        self.generator = coshsh.generator.Generator()
        self.generator.setup_logging()

    def test_growing_hosts(self):
        self.print_header()

        # create 100 hosts
        # recipes/test15/data
        self.generator.add_recipe(name='test15', **dict(self.config.items('recipe_TEST15')))
        self.config.set("datasource_CSVSHRINK", "name", "csvshrink")
        cfg = self.config.items("datasource_CSVSHRINK")
        self.generator.recipes['test15'].add_datasource(**dict(cfg))
        print "---->", self.generator.recipes['test15']
        print "mkdir", cfg
        dir = [t[1] for t in cfg if t[0] == 'dir'][0]
        name = [t[1] for t in cfg if t[0] == 'name'][0]
        hosts = os.path.join(dir, name + '_hosts.csv')
        targetdir = './var/objects/test15'
        shutil.rmtree(dir, True)
        shutil.rmtree(targetdir, True)
        print "removed", dir
        os.makedirs(dir)
        with open(hosts, 'a') as f:
            f.write('host_name,address,type,os,hardware,virtual,notification_period,location,department\n')
            for i in range(0,10):
                f.write('test_host_%03d,127.0.0.1,server,,Proliant DL380 G6,ps,7x24,rack1,versandverpackung\n' % i)

        # remove target dir / create empty
        self.generator.recipes['test15'].count_before_objects()
        self.generator.recipes['test15'].cleanup_target_dir()

        self.generator.recipes['test15'].prepare_target_dir()
        # check target

        # read the datasources
        self.generator.recipes['test15'].collect()

        # for each host, application get the corresponding template files
        # get the template files and cache them in a struct owned by the recipe
        # resolve the templates and attach the result as config_files to host/app
        self.generator.recipes['test15'].render()
        self.assert_(hasattr(self.generator.recipes['test15'].objects['hosts']['test_host_000'], 'config_files'))
        self.assert_('host.cfg' in self.generator.recipes['test15'].objects['hosts']['test_host_000'].config_files)
        self.assert_(hasattr(self.generator.recipes['test15'].objects['hosts']['test_host_009'], 'config_files'))
        self.assert_('host.cfg' in self.generator.recipes['test15'].objects['hosts']['test_host_009'].config_files)

        # write hosts/apps to the filesystem
        self.generator.recipes['test15'].output()
        self.assert_(os.path.exists("var/objects/test15/dynamic/hosts"))
        self.assert_(os.path.exists("var/objects/test15/dynamic/hosts/test_host_000"))
        self.assert_(os.path.exists("var/objects/test15/dynamic/hosts/test_host_000/host.cfg"))
        self.assert_(os.path.exists("var/objects/test15/dynamic/hosts/test_host_009"))
        self.assert_(os.path.exists("var/objects/test15/dynamic/hosts/test_host_009/host.cfg"))

        save_dir = os.getcwd()
        os.chdir('./var/objects/test15/dynamic')
        process = Popen(["git", "init", "."], stdout=PIPE, stderr=STDOUT)
        output, unused_err = process.communicate()
        retcode = process.poll()
        print output
        process = Popen(["git", "add", "."], stdout=PIPE, stderr=STDOUT)
        output, unused_err = process.communicate()
        retcode = process.poll()
        print output
        process = Popen(["git", "commit", "-a", "-m", "commit init"], stdout=PIPE, stderr=STDOUT)
        output, unused_err = process.communicate()
        retcode = process.poll()
        print output
        os.chdir(save_dir)

        with open(hosts, 'a') as f:
            for i in range(10,20):
                f.write('test_host_%03d,127.0.0.1,server,,Proliant DL380 G6,ps,7x24,rack1,versandverpackung\n' % i)

        self.clean_generator()
        self.generator.add_recipe(name='test15', **dict(self.config.items('recipe_TEST15')))
        self.config.set("datasource_CSVSHRINK", "name", "csvshrink")
        cfg = self.config.items("datasource_CSVSHRINK")
        self.generator.recipes['test15'].add_datasource(**dict(cfg))

        self.generator.recipes['test15'].collect()
        self.generator.recipes['test15'].render()

        self.assert_(hasattr(self.generator.recipes['test15'].objects['hosts']['test_host_010'], 'config_files'))
        self.assert_('host.cfg' in self.generator.recipes['test15'].objects['hosts']['test_host_010'].config_files)
        self.assert_(hasattr(self.generator.recipes['test15'].objects['hosts']['test_host_019'], 'config_files'))
        self.assert_('host.cfg' in self.generator.recipes['test15'].objects['hosts']['test_host_019'].config_files)

        # write hosts/apps to the filesystem
        self.generator.recipes['test15'].output()

        # we violated the delta
        self.assert_(os.path.exists("var/objects/test15/dynamic/hosts"))
        self.assert_(os.path.exists("var/objects/test15/dynamic/hosts/test_host_000"))
        self.assert_(os.path.exists("var/objects/test15/dynamic/hosts/test_host_000/host.cfg"))
        self.assert_(os.path.exists("var/objects/test15/dynamic/hosts/test_host_009/host.cfg"))
        # the hosts 10..20 were automatically resetted and cleaned by the
        # max_delta_action
        self.assert_(not os.path.exists("var/objects/test15/dynamic/hosts/test_host_019"))


    def test_grow_grow_ok(self):
        self.print_header()

        self.generator.add_recipe(name='test16', **dict(self.config.items('recipe_TEST16')))
        self.config.set("datasource_CSVSHRINK", "name", "csvshrink")
        cfg = self.config.items("datasource_CSVSHRINK")
        self.generator.recipes['test16'].add_datasource(**dict(cfg))
        print "---->", self.generator.recipes['test16']
        print "mkdir", cfg
        dir = [t[1] for t in cfg if t[0] == 'dir'][0]
        name = [t[1] for t in cfg if t[0] == 'name'][0]
        hosts = os.path.join(dir, name + '_hosts.csv')
        targetdir = './var/objects/test16'
        shutil.rmtree(dir, True)
        shutil.rmtree(targetdir, True)
        print "removed", dir
        os.makedirs(dir)
        with open(hosts, 'a') as f:
            f.write('host_name,address,type,os,hardware,virtual,notification_period,location,department\n')
            for i in range(0,10):
                f.write('test_host_%03d,127.0.0.1,server,,Proliant DL380 G6,ps,7x24,rack1,versandverpackung\n' % i)

        # remove target dir / create empty
        self.generator.recipes['test16'].count_before_objects()
        self.generator.recipes['test16'].cleanup_target_dir()

        self.generator.recipes['test16'].prepare_target_dir()
        # check target

        # read the datasources
        self.generator.recipes['test16'].collect()

        # for each host, application get the corresponding template files
        # get the template files and cache them in a struct owned by the recipe
        # resolve the templates and attach the result as config_files to host/app
        self.generator.recipes['test16'].render()
        self.assert_(hasattr(self.generator.recipes['test16'].objects['hosts']['test_host_000'], 'config_files'))
        self.assert_('host.cfg' in self.generator.recipes['test16'].objects['hosts']['test_host_000'].config_files)
        self.assert_(hasattr(self.generator.recipes['test16'].objects['hosts']['test_host_009'], 'config_files'))
        self.assert_('host.cfg' in self.generator.recipes['test16'].objects['hosts']['test_host_009'].config_files)

        # write hosts/apps to the filesystem
        self.generator.recipes['test16'].output()
        self.assert_(os.path.exists("var/objects/test16/dynamic/hosts"))
        self.assert_(os.path.exists("var/objects/test16/dynamic/hosts/test_host_000"))
        self.assert_(os.path.exists("var/objects/test16/dynamic/hosts/test_host_000/host.cfg"))
        self.assert_(os.path.exists("var/objects/test16/dynamic/hosts/test_host_009"))
        self.assert_(os.path.exists("var/objects/test16/dynamic/hosts/test_host_009/host.cfg"))

        save_dir = os.getcwd()
        os.chdir('./var/objects/test16/dynamic')
        process = Popen(["git", "init", "."], stdout=PIPE, stderr=STDOUT)
        output, unused_err = process.communicate()
        retcode = process.poll()
        print output
        process = Popen(["git", "add", "."], stdout=PIPE, stderr=STDOUT)
        output, unused_err = process.communicate()
        retcode = process.poll()
        print output
        process = Popen(["git", "commit", "-a", "-m", "commit init"], stdout=PIPE, stderr=STDOUT)
        output, unused_err = process.communicate()
        retcode = process.poll()
        print output
        os.chdir(save_dir)

        print "and ten more hosts"
        with open(hosts, 'a') as f:
            for i in range(10,20):
                f.write('test_host_%03d,127.0.0.1,server,,Proliant DL380 G6,ps,7x24,rack1,versandverpackung\n' % i)

        self.clean_generator()
        self.generator.add_recipe(name='test16', **dict(self.config.items('recipe_TEST16')))
        self.config.set("datasource_CSVSHRINK", "name", "csvshrink")
        cfg = self.config.items("datasource_CSVSHRINK")
        self.generator.recipes['test16'].add_datasource(**dict(cfg))

        self.generator.recipes['test16'].collect()
        self.generator.recipes['test16'].render()

        self.assert_(hasattr(self.generator.recipes['test16'].objects['hosts']['test_host_010'], 'config_files'))
        self.assert_('host.cfg' in self.generator.recipes['test16'].objects['hosts']['test_host_010'].config_files)
        self.assert_(hasattr(self.generator.recipes['test16'].objects['hosts']['test_host_019'], 'config_files'))
        self.assert_('host.cfg' in self.generator.recipes['test16'].objects['hosts']['test_host_019'].config_files)

        # write hosts/apps to the filesystem
        self.generator.recipes['test16'].output()

        # we violated the delta
        self.assert_(os.path.exists("var/objects/test16/dynamic/hosts"))
        self.assert_(os.path.exists("var/objects/test16/dynamic/hosts/test_host_000"))
        self.assert_(os.path.exists("var/objects/test16/dynamic/hosts/test_host_000/host.cfg"))
        self.assert_(os.path.exists("var/objects/test16/dynamic/hosts/test_host_009/host.cfg"))
        self.assert_(os.path.exists("var/objects/test16/dynamic/hosts/test_host_019"))


    def test_shrinking_hosts(self):
        self.print_header()

        self.generator.add_recipe(name='test16', **dict(self.config.items('recipe_TEST16')))
        self.config.set("datasource_CSVSHRINK", "name", "csvshrink")
        cfg = self.config.items("datasource_CSVSHRINK")
        self.generator.recipes['test16'].add_datasource(**dict(cfg))
        print "---->", self.generator.recipes['test16']
        print "mkdir", cfg
        dir = [t[1] for t in cfg if t[0] == 'dir'][0]
        name = [t[1] for t in cfg if t[0] == 'name'][0]
        hosts = os.path.join(dir, name + '_hosts.csv')
        targetdir = './var/objects/test16'
        shutil.rmtree(dir, True)
        shutil.rmtree(targetdir, True)
        print "removed", dir
        os.makedirs(dir)
        with open(hosts, 'a') as f:
            f.write('host_name,address,type,os,hardware,virtual,notification_period,location,department\n')
            for i in range(0,10):
                f.write('test_host_%03d,127.0.0.1,server,,Proliant DL380 G6,ps,7x24,rack1,versandverpackung\n' % i)

        # remove target dir / create empty
        self.generator.recipes['test16'].count_before_objects()
        self.generator.recipes['test16'].cleanup_target_dir()

        self.generator.recipes['test16'].prepare_target_dir()
        # check target

        # read the datasources
        self.generator.recipes['test16'].collect()

        # for each host, application get the corresponding template files
        # get the template files and cache them in a struct owned by the recipe
        # resolve the templates and attach the result as config_files to host/app
        self.generator.recipes['test16'].render()
        self.assert_(hasattr(self.generator.recipes['test16'].objects['hosts']['test_host_000'], 'config_files'))
        self.assert_('host.cfg' in self.generator.recipes['test16'].objects['hosts']['test_host_000'].config_files)
        self.assert_(hasattr(self.generator.recipes['test16'].objects['hosts']['test_host_009'], 'config_files'))
        self.assert_('host.cfg' in self.generator.recipes['test16'].objects['hosts']['test_host_009'].config_files)

        # write hosts/apps to the filesystem
        self.generator.recipes['test16'].output()
        self.assert_(os.path.exists("var/objects/test16/dynamic/hosts"))
        self.assert_(os.path.exists("var/objects/test16/dynamic/hosts/test_host_000"))
        self.assert_(os.path.exists("var/objects/test16/dynamic/hosts/test_host_000/host.cfg"))
        self.assert_(os.path.exists("var/objects/test16/dynamic/hosts/test_host_009"))
        self.assert_(os.path.exists("var/objects/test16/dynamic/hosts/test_host_009/host.cfg"))

        save_dir = os.getcwd()
        os.chdir('./var/objects/test16/dynamic')
        process = Popen(["git", "init", "."], stdout=PIPE, stderr=STDOUT)
        output, unused_err = process.communicate()
        retcode = process.poll()
        print output
        process = Popen(["git", "add", "."], stdout=PIPE, stderr=STDOUT)
        output, unused_err = process.communicate()
        retcode = process.poll()
        print output
        process = Popen(["git", "commit", "-a", "-m", "commit init"], stdout=PIPE, stderr=STDOUT)
        output, unused_err = process.communicate()
        retcode = process.poll()
        print output
        os.chdir(save_dir)

        shutil.rmtree(hosts, True)
        with open(hosts, 'w') as f:
            f.write('host_name,address,type,os,hardware,virtual,notification_period,location,department\n')
            for i in range(0,2):
                f.write('test_host_%03d,127.0.0.1,server,,Proliant DL380 G6,ps,7x24,rack1,versandverpackung\n' % i)

        self.clean_generator()
        self.generator.add_recipe(name='test16', **dict(self.config.items('recipe_TEST16')))
        self.config.set("datasource_CSVSHRINK", "name", "csvshrink")
        cfg = self.config.items("datasource_CSVSHRINK")
        self.generator.recipes['test16'].add_datasource(**dict(cfg))

        self.generator.recipes['test16'].collect()
        self.generator.recipes['test16'].render()

        self.assert_(hasattr(self.generator.recipes['test16'].objects['hosts']['test_host_000'], 'config_files'))
        self.assert_('host.cfg' in self.generator.recipes['test16'].objects['hosts']['test_host_000'].config_files)
        self.assert_('test_host_001' in self.generator.recipes['test16'].objects['hosts'])
        self.assert_('test_host_002' not in self.generator.recipes['test16'].objects['hosts'])

        # write hosts/apps to the filesystem
        self.generator.recipes['test16'].output()

        # we violated the delta
        self.assert_(os.path.exists("var/objects/test16/dynamic/hosts"))
        self.assert_(os.path.exists("var/objects/test16/dynamic/hosts/test_host_000"))
        self.assert_(os.path.exists("var/objects/test16/dynamic/hosts/test_host_000/host.cfg"))
        self.assert_(os.path.exists("var/objects/test16/dynamic/hosts/test_host_009/host.cfg"))
        # the hosts 10..20 were automatically resetted and cleaned by the
        # max_delta_action
        self.assert_(not os.path.exists("var/objects/test16/dynamic/hosts/test_host_019"))


if __name__ == '__main__':
    unittest.main()





import os
import coshsh
from coshsh.application import Application
from coshsh.templaterule import TemplateRule
from coshsh.util import compare_attr, is_attr

def __mi_ident__(params={}):
    if coshsh.util.is_attr("name", params, "os") and coshsh.util.compare_attr("type", params, ".*red\s*hat.*|.*rhel.*|.*sles.*|.*linux.*|.*limux.*|.*debian.*|.*ubuntu.*|.*centos.*"):
        return Linux


class Linux(coshsh.application.Application):
    template_rules = [
        coshsh.templaterule.TemplateRule(needsattr=None, 
            template="os_linux_default"),
        coshsh.templaterule.TemplateRule(needsattr="filesystems", 
            template="os_linux_fs"),
    ]

    def wemustrepeat(self):
        self.SSHPORT = getattr(self, 'SSHPORT', 22)
        self.SSHUSER = getattr(self, 'SSHUSER', os.environ.get('OMD_CLIENT_USER_LINUX', 'mon'))
        self.SSHPATHPREFIX = getattr(self, 'SSHPATHPREFIX', os.environ.get('OMD_CLIENT_PATH_PREFIX', '.'))
        if not hasattr(self, 'custom_macros'):
            self.custom_macros = {}
        self.custom_macros['_SSHPORT'] = self.SSHPORT
        self.custom_macros['_SSHUSER'] = self.SSHUSER
        self.custom_macros['_SSHPATHPREFIX'] = self.SSHPATHPREFIX
        # auch als host-macros, denn damit kann man check_by_ssh mit
        # $_HOSTSSHUSER$ benutzen und muss irgenwelchen (teils generischen)
        # app_-Applikationen nicht auch noch diese Macros verpassen.
        if not hasattr(self.host, 'custom_macros'):
            self.host.custom_macros = {}
        self.host.custom_macros['_SSHPORT'] = self.SSHPORT
        self.host.custom_macros['_SSHUSER'] = self.SSHUSER
        self.host.custom_macros['_SSHPATHPREFIX'] = self.SSHPATHPREFIX


class EmbeddedLinux(Linux):
    template_rules = [
        coshsh.templaterule.TemplateRule(needsattr=None, 
            template="os_linux_heartbeat"),
    ]




import coshsh
from coshsh.application import Application
from coshsh.templaterule import TemplateRule
from coshsh.util import compare_attr, is_attr

def __mi_ident__(params={}):
    if coshsh.util.is_attr("name", params, "os") and coshsh.util.compare_attr("type", params, ".*windows.*"):
        return Windows


class Windows(Application):
    template_rules = [
        coshsh.templaterule.TemplateRule(needsattr=None, 
            template="os_windows_default"),
        coshsh.templaterule.TemplateRule(needsattr="filesystems", 
            template="os_windows_fs"),
    ]

    def wemustrepeat(self):
        self.NSCPORT = getattr(self, 'NSCPORT', 18443)
        self.NSCPASSWORD = getattr(self, 'NSCPASSWORD', 'secret')
        if not hasattr(self, 'custom_macros'):
            self.custom_macros = {}
        self.custom_macros['_NSCPORT'] = self.NSCPASSWORD
        self.custom_macros['_NSCPASSWORD'] = self.NSCPASSWORD
        if not hasattr(self.host, 'custom_macros'):
            self.host.custom_macros = {}
        self.host.custom_macros['_NSCPORT'] = self.NSCPASSWORD
        self.host.custom_macros['_NSCPASSWORD'] = self.NSCPASSWORD

